/**
 *******************************************************************************
 * @file    tmpm363_rc.c
 * @brief   This file provides API functions for RC driver.
 * @version V2.0.2.2
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm363_rc.h"

#if defined(__TMPM360_RC_H) || defined(__TMPM361_RC_H) || defined(__TMPM362_RC_H) || defined(__TMPM363_RC_H) || defined(__TMPM364_RC_H)
/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @defgroup RC 
  * @brief RC driver modules
  * @{
  */

/** @defgroup RC_Private_Defines
  * @{
  */
#define RCWAIT_RAMWAIT_SET     ((uint32_t)0x00000001)
#define RCWAIT_RAMWAIT_CLEAR   ((uint32_t)0x00000000)

#define RCWAIT_RAMWAIT_MASK    ((uint32_t)0x00000001)
#define RCWAIT_RAMWAIT_FLAG    ((uint32_t)0x00000001)

/** @} */
/* End of group RC_Private_Defines */

/** @defgroup RC_Private_FunctionPrototypes
  * @{
  */

/** @} */
/* End of group RC_Private_FunctionPrototypes */

/** @defgroup RC_Private_Functions
  * @{
  */

/** @} */
/* End of group RC_Private_Functions */

/** @defgroup RC_Exported_Functions
  * @{
  */



/**
  * @brief  Set the value of RCWAIT register.
  * @param  RAMWait: The value of RCWAIT register.
  *   This parameter can be one of the following values:
  *   RC_RAMWAIT_0 or RC_RAMWAIT_1.
  * @retval None
  */
void RC_SetRAMWait(RC_RAMWait RAMWait)
{
    uint32_t tmp = TSB_RC->WAIT;
    /* Check the parameters */
    assert_param(IS_RC_RAMWAIT(RAMWait));

    if (RAMWait == RC_RAMWAIT_1) {
        /* Set RCWAIT<RAM1WAIT> to "1" */
        tmp |= RCWAIT_RAMWAIT_SET;
    } else {
        /* Set RCWAIT<RAM1WAIT> to "0" */
        tmp &= RCWAIT_RAMWAIT_CLEAR;
    }
    TSB_RC->WAIT = tmp;
}

/**
  * @brief  Get the value of RCWAIT register.
  * @param  None
  * @retval RC_RAMWAIT_0 or RC_RAMWAIT_1
  *
  */
RC_RAMWait RC_GetRAMWait(void)
{
    uint32_t tmp = 0U;
    RC_RAMWait retval = RC_RAMWAIT_1;

    tmp = TSB_RC->WAIT & RCWAIT_RAMWAIT_MASK;

    /* Check RAMWait flag */
    if (tmp == RCWAIT_RAMWAIT_FLAG) {
        retval = RC_RAMWAIT_1;
    } else {
        retval = RC_RAMWAIT_0;
    }
    return retval;
}

/** @} */
/* End of group RC_Exported_Functions */

/** @} */
/* End of group RC */

/** @} */
/* End of group TX03_Periph_Driver */
#endif                          /* (__TMPM360_RC_H) || (__TMPM361_RC_H) || (__TMPM362_RC_H) || (__TMPM363_RC_H) || (__TMPM364_RC_H) */
