/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of CEC demo for the TOSHIBA
 *          'TMPM363' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "tmpm363_cec.h"
#include <stdio.h>

typedef enum {
    DATA_INIT = 0,
    DATA_IN_PROGRESS = 1,
    DATA_END = 2
} CEC_DataState;

typedef struct {
    CEC_LogicalAddr Initiator;
    CEC_LogicalAddr Destination;
    uint8_t Opcode;
    uint8_t CEC_Data[17];
    uint8_t current_num;
    uint8_t Max_num;
    CEC_DataState current_state;
} CEC_FrameTypeDef;

CEC_FrameTypeDef CEC_RxFrame;
CEC_FrameTypeDef CEC_RxFrameTmp;
CEC_FrameTypeDef CEC_TxFrame;

void CEC_Send_Frame(CEC_LogicalAddr Initiator, CEC_LogicalAddr Destination,
                    uint8_t Opcode, uint8_t OperandNum, uint8_t Operand[17]);

int main(void)
{
    uint32_t Index = 0U;
    uint32_t temp = 0U;
    SystemInit();
    /*initial cec port */
    TSB_PI->CR = 0x01U;
    TSB_PI->FR1 = 0x01U;
    TSB_PI->IE = 0x01U;
    /*initial cec frame data buffer */
    CEC_RxFrame.Initiator = CEC_UNKNOWN;
    CEC_RxFrame.Destination = CEC_UNKNOWN;
    CEC_RxFrame.Opcode = 0xFFU;
    CEC_RxFrame.current_num = 0x0U;
    CEC_RxFrame.Max_num = 0x0U;
    CEC_RxFrame.current_state = DATA_INIT;
    for (Index = 0U; Index < 17U; Index++) {
        CEC_RxFrame.CEC_Data[Index] = 0xFFU;
    }
    CEC_RxFrameTmp = CEC_RxFrame;
    CEC_TxFrame = CEC_RxFrame;
    /*initial cec register */
    CEC_Enable();
    CEC_SWReset();
    while (CEC_GetRxState() == ENABLE);
    while (CEC_GetTxState() == BUSY);
    CEC_DefaultConfig();

    /*initial cec interupt */
    __disable_irq();
    TSB_CG->IMCGE = 0x00003030U;
    TSB_CG->IMCGE = 0x00003131U;
    TSB_CG->ICRCG = 0x10U;
    NVIC_EnableIRQ(INTCECRX_IRQn);
    NVIC_EnableIRQ(INTCECTX_IRQn);
    __enable_irq();

    /*set logical address TV */
    CEC_SetLogicalAddr(CEC_TV);
    /*Enable CEC reception */
    CEC_SetRxCtrl(ENABLE);

    while (1) {
        /*Recieve new frame or not */
        if (CEC_RxFrameTmp.current_state == DATA_END) {
            CEC_RxFrame = CEC_RxFrameTmp;
            CEC_RxFrameTmp.current_num = 0U;
            CEC_RxFrameTmp.current_state = DATA_INIT;
            temp = CEC_RxFrame.current_num;
#ifdef DEBUG
            if (temp > 0U) {
                printf("CEC Message: ");
                for (Index = 0U; Index < temp; Index++) {
                    printf("0x%2x ", CEC_RxFrame.CEC_Data[Index]);
                }
                printf("\n");
            }
#endif
            for (Index = 0U; Index < 17U; Index++) {
                CEC_RxFrameTmp.CEC_Data[Index] = 0xFFU;
            }
            /*CEC message is "Active Source" */
            if (CEC_RxFrame.CEC_Data[1] == 0x82U) {
                CEC_Send_Frame(CEC_TV, CEC_BROADCAST, 0x36U, 0U, CEC_RxFrame.CEC_Data);
            }
        }
    }
}

/**
  * @brief  Send A frame to other device.
  * @param  Initiator: Initiaor address ,Destination: Destination address, Opcode: operate code, OperandNum: Operand number,CEC_Data: CEC frame data
  * @retval None
  */
void CEC_Send_Frame(CEC_LogicalAddr Initiator, CEC_LogicalAddr Destination,
                    uint8_t Opcode, uint8_t OperandNum, uint8_t CEC_Data[17])
{
    uint32_t Index = 0U;
    if (CEC_TxFrame.current_state != DATA_IN_PROGRESS) {
        CEC_TxFrame.Initiator = Initiator;
        CEC_TxFrame.Destination = Destination;
        CEC_TxFrame.current_num = 0U;
        CEC_TxFrame.Opcode = Opcode;
        CEC_TxFrame.Max_num = 2U + OperandNum;
        CEC_TxFrame.current_state = DATA_IN_PROGRESS;
        CEC_TxFrame.CEC_Data[0] = (uint8_t) Initiator << 4U;
        CEC_TxFrame.CEC_Data[0] |= ((uint8_t) Destination);
        CEC_TxFrame.CEC_Data[1] = Opcode;

        for (Index = 2U; Index < 17U; Index++) {
            if (Index < CEC_TxFrame.Max_num) {
                CEC_TxFrame.CEC_Data[Index] = CEC_Data[Index];
            } else {
                CEC_TxFrame.CEC_Data[Index] = 0xFFU;
            }
        }
        if (CEC_BROADCAST == Destination) {
            CEC_SetTxBroadcast(ENABLE);
        } else {
            CEC_SetTxBroadcast(DISABLE);
        }
        /*Send first byte of frame */
        CEC_SetTxData(CEC_TxFrame.CEC_Data[0], CEC_NO_EOM);
        CEC_StartTx();
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
