/**
 *******************************************************************************
 * @file    tmpm363_rmc_int.c
 * @brief   all interrupt request functions prototypes of RMC
 *          for the TOSHIBA 'TMPM363' Device Series
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm363_rmc_int.h"
#include "main.h"

RMCRX fRMCRx = None;
uint32_t RMC_Command;
void INTRMCRX0_IRQHandler(void)
{
    RMC_INTFactor myRMC_INTFactor;
    RMC_RxDataTypeDef myRMC_RxDataDef;
#ifdef TOSHIBA_FORMAT_RMC
    RMC_LeaderDetection myRMC_LeaderDetection;
#endif

    myRMC_INTFactor = RMC_GetINTFactor(TSB_RMC0);
#ifdef TOSHIBA_FORMAT_RMC
    if (myRMC_INTFactor.Bit.MaxDataBitCycle) {  /*Max data bit cycle detection interrupt factor */
        myRMC_LeaderDetection = RMC_GetLeader(TSB_RMC0);
        if (myRMC_LeaderDetection == RMC_LEADER_DETECTED) {     /*Leader has been detected */
            myRMC_RxDataDef = RMC_GetRxData(TSB_RMC0);
            if (myRMC_RxDataDef.RxDataBits == 0x20U) {  /*32 bits data received */
                fRMCRx = Received;
                RMC_Command = myRMC_RxDataDef.RxBuf1;   /* save the RMC data for print in main() */
            }
        }
    }
#endif

#ifdef RC5_FORMAT_RMC
    if (myRMC_INTFactor.Bit.LowWidthDetection) {        /*Low width detection interrupt factor */
        myRMC_RxDataDef = RMC_GetRxData(TSB_RMC0);
        if (myRMC_RxDataDef.RxDataBits == 0x0EU) {      /*14 bits data received */
            fRMCRx = Received;
            RMC_Command = myRMC_RxDataDef.RxBuf1;       /* save the RMC data for print in main() */
        }
    }
#endif

    TSB_CG->ICRCG = 0x00000012U;      /* clear RMC0 INT */
}
