/**
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of RTC demo for the
 *          TOSHIBA Cortex-M3 TMPM363F10FG
 * @version V1.001
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* include file */
#include "tmpm363_rtc.h"
#include "tmpm363_rtc_int.h"

#include "led.h"

#define CG_IMCGC_RTC_EDGE		((uint32_t)0x00000020)	/* RTC Interrupt Edge */
#define CG_IMCGC_RTC_INTEN		((uint32_t)0x00000021)	/* RTC Interrupt ON   */

#ifdef DEBUG
#include "stdio.h"
#endif

void DisplayLED(void);

/* User ram definition  */
RTC_DateTypeDef Date_Struct;
RTC_TimeTypeDef Time_Struct;

uint8_t Year;
uint8_t Month;
uint8_t Date;
uint8_t Day;
uint8_t Hour;
uint8_t Min;
uint8_t Sec;

/* main function */
int main(void)
{
    SystemInit();
    LED_Configuration();

    __disable_irq();
    /* enable RTC interrupt */
    NVIC_ClearPendingIRQ(INTRTC_IRQn);
    TSB_CG->IMCGF = CG_IMCGC_RTC_EDGE;
    TSB_CG->IMCGF = CG_IMCGC_RTC_INTEN;
    NVIC_EnableIRQ(INTRTC_IRQn);

    Date_Struct.LeapYear = RTC_LEAP_YEAR_2;
    Date_Struct.Year = (uint8_t) 10;
    Date_Struct.Month = (uint8_t) 12;
    Date_Struct.Date = (uint8_t) 31;
    Date_Struct.Day = RTC_FRI;

    Time_Struct.HourMode = RTC_12_HOUR_MODE;
    Time_Struct.Hour = (uint8_t) 11;
    Time_Struct.AmPm = RTC_PM_MODE;
    Time_Struct.Min = (uint8_t) 59;
    Time_Struct.Sec = (uint8_t) 50;

    RTC_DisableClock();
    RTC_DisableAlarm();

    /* Reset RTC sec counter */
    RTC_ResetClockSec();
    /* Set RTC Time value */
    RTC_SetTimeValue(&Time_Struct);
    /* Set RTC Date value */
    RTC_SetDateValue(&Date_Struct);

    /* Enable 1Hz interrupt */
    RTC_SetAlarmOutput(RTC_PULSE_1_HZ);
    /* Enable RTCINT */
    RTC_SetRTCINT(ENABLE);
    __enable_irq();

    /* waiting for RTC register set finish */
    while (fRTCSetting_ok != 1U) {
        /* Do nothing */
    }
    fRTCSetting_ok = 0U;

    /* Disable RTCINT */
    __disable_irq();
    RTC_SetRTCINT(DISABLE);
    NVIC_DisableIRQ(INTRTC_IRQn);
    __enable_irq();

    /* Enable RTC Clock function */
    RTC_EnableClock();

    while (1) {
        DisplayLED();
    }
}


/* display second on LED as binary format */
void DisplayLED(void)
{
    uint8_t tmp;

#ifdef DEBUG
    const uint8_t *idx2Day[] = { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" };
#endif

    RTC_GetTimeValue(&Time_Struct);
    tmp = Time_Struct.Sec % 10;
    LED_Display(tmp);

#ifdef DEBUG
    if ((tmp % 10) == 0) {
        RTC_GetDateValue(&Date_Struct);

        /* note: in IAR EWARM, can use View->Terminal I/O to watch the result, but it occupys about 2sec to run 'printf' */
        printf("Current Date: %2d-%2d-%2d, Current Day: %s\n",
            Date_Struct.Year,Date_Struct.Month,Date_Struct.Date, idx2Day[Date_Struct.Day]);
    } else {
        /* do nothing */
    }
#endif



}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
