/**
 *******************************************************************************
 * @file    tmpm363_sbi_int.c
 * @brief   all interrupt request functions definition of Read EEPROM demo
 *          for the TOSHIBA 'TMPM363' Device Series 
 * @version V1.001
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm363_sbi_int.h"

void INTSBI2_IRQHandler(void)
{
    uint32_t tmp = 0U;
    TSB_SBI_TypeDef *SBIx;
    SBI_I2CState sbi_sr;
    
    SBIx = TSB_SBI2;
    sbi_sr = SBI_GetI2CState(SBIx);

    if (sbi_sr.Bit.MasterSlave) {       /* Master mode     */
        if (sbi_sr.Bit.TRx) {   /* Tx mode        */
            if (sbi_sr.Bit.LastRxBit) {       /* LRB=1: the receiver requires no further data. */
                SBI_GenerateI2CStop(SBIx);
            } else {            /* LRB=0: the receiver requires further data. */
                if (gI2C_WCnt < gI2C_TxDataLen) {
                    SBI_SetSendData(SBIx, gI2C_TxData[gI2C_WCnt]);      /* Send next data */
                } else if (gI2C_WCnt == gI2C_TxDataLen) {       /* I2C data send finished. */
                    SBI_GenerateI2CStop(SBIx);
                } else {
                    /* Do nothing */
                }
                gI2C_WCnt++;
            }
        } else {                /* Rx Mode */

            if (gI2C_RCnt > gI2C_RxDataLen) {
                SBI_GenerateI2CStop(SBIx);
            } else {
                if (gI2C_RCnt == gI2C_RxDataLen) {      /* Rx last data */
                    SBI_SetI2CBitNum(SBIx, SBI_I2C_DATA_LEN_1);
                } else if (gI2C_RCnt == (gI2C_RxDataLen - 1U)) {        /* Rx the data second to last */
                    /* Not generate ACK for next data Rx end. */
                    SBI_SetI2CACK(SBIx, DISABLE);
                } else {
                    /* Do nothing */
                }
                tmp = SBI_GetReceiveData(SBIx);
                if (gI2C_RCnt > 0U) {
                    gI2C_RxData[gI2C_RCnt - 1U] = tmp;
                } else {
                    /* first read is dummy read */
                }
                gI2C_RCnt++;
            }
        }
    } else {                    /* Slave mode  */

    }

}
