/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA TMPM36x Device Series
 * @version  V0.101
 * @date     2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */
#include "led.h"

/*******************************************************************************
* Function Name  : LED_IO
* Description    : Config the GPIO to LED 
* Input          : None 
* Return         : None.
*******************************************************************************/
void LED_IO(void)
{
    TSB_PM->CR = (uint32_t) 0xF0;
    TSB_PM->PUP = (uint32_t) 0xF0;
}

/*******************************************************************************
* Function Name  : LED_Display
* Description    : Turn on or off LED
* Input          : ucLED
* Return         : None.
*******************************************************************************/
void LED_Display(uint8_t ucLED)
{
    uint8_t tmp = 0U;
    tmp = (uint8_t) ucLED << 4U;
    tmp = ~tmp;
    TSB_PM->DATA = (uint32_t) tmp;
}


/*******************************************************************************
* Function Name  : LED_Configuration
* Description    : Configures LED
* Input          : None.
* Return         : None.
*******************************************************************************/
void LED_Configuration(void)
{
    LED_IO();

    /* LED initialization state */
    LED_Display(LEDALL_OFF);
}

/*******************************************************************************
* Function Name  : LED_On
* Description    : Turn on LED
* Input          : ucLED
* Return         : None.
*******************************************************************************/
void LED_On(uint8_t ucLED)
{
    if ((ucLED & LED1) != 0U) {
        TSB_PM_DATA_PM4 = 0U;
    }
    if ((ucLED & LED2) != 0U) {
        TSB_PM_DATA_PM5 = 0U;
    }
    if ((ucLED & LED3) != 0U) {
        TSB_PM_DATA_PM6 = 0U;
    }
    if ((ucLED & LED4) != 0U) {
        TSB_PM_DATA_PM7 = 0U;
    }
}

/*******************************************************************************
* Function Name  : LED_Off
* Description    : Turn off LED
* Input          : ucLED
* Return         : None.
*******************************************************************************/
void LED_Off(uint8_t ucLED)
{
    if ((ucLED & LED1) != 0U) {
        TSB_PM_DATA_PM4 = 1U;
    }
    if ((ucLED & LED2) != 0U) {
        TSB_PM_DATA_PM5 = 1U;
    }
    if ((ucLED & LED3) != 0U) {
        TSB_PM_DATA_PM6 = 1U;
    }
    if ((ucLED & LED4) != 0U) {
        TSB_PM_DATA_PM7 = 1U;
    }
}

/*******************************************************************************
* Function Name  : LED_Toggle
* Description    : Toggle LED
* Input          : None.
* Return         : None.
*******************************************************************************/
void LED_Toggle(uint8_t ucLED)
{
    if ((ucLED & LED1) != 0U) {
        TSB_PM_DATA_PM4 = !TSB_PM_DATA_PM4;
    }
    if ((ucLED & LED2) != 0U) {
        TSB_PM_DATA_PM5 = !TSB_PM_DATA_PM5;
    }
    if ((ucLED & LED3) != 0U) {
        TSB_PM_DATA_PM6 = !TSB_PM_DATA_PM6;
    }
    if ((ucLED & LED4) != 0U) {
        TSB_PM_DATA_PM7 = !TSB_PM_DATA_PM7;
    }
}
